# Table of Contents

- [configuring-sso-with-okta](<./configuring-sso-with-okta.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring SSO with Okta](<./Configuring-SSO-with-Okta.md>)
  - [Prerequisites](<./Configuring-SSO-with-Okta/Prerequisites.md>)
  - [Step 1: Create an Application for SSO](<./Configuring-SSO-with-Okta/Step-1-Create-an-Application-for-SSO.md>)
  - [Step 2: Configure SAML Settings](<./Configuring-SSO-with-Okta/Step-2-Configure-SAML-Settings.md>)
  - [Step 3: Configure Attribute Mapping](<./Configuring-SSO-with-Okta/Step-3-Configure-Attribute-Mapping.md>)
  - [Step 4: Assign Users to the Application](<./Configuring-SSO-with-Okta/Step-4-Assign-Users-to-the-Application.md>)
  - [Was this page helpful?](<./Configuring-SSO-with-Okta/Was-this-page-helpful.md>)
